@@ -942,8 +942,14 @@ def relationship2dict(relationship: neo4j.data.Relationship):
             "type": relationship.type, "properties": relationship._properties}
 
 
+def path2dict(path: neo4j.graph.Path):
+    return {"start_node": node2dict(path.start_node), "end_node": node2dict(path.end_node),
+            "nodes": [node2dict(n) for n in path.nodes],
+            "relationships": [relationship2dict(r) for r in path.relationships]}
+
+
 def parse_record(record: neo4j.data.Record, flag=True):
-    _record = {"node": [], "relationship": [], "other": []}
+    _record = {"node": [], "relationship": [], "path": [], "other": []}
     if isinstance(record, neo4j.data.Record):
         for rd in record:
             if isinstance(rd, neo4j.data.Node):
@@ -964,8 +970,12 @@ def parse_record(record: neo4j.data.Record, flag=True):
                         _record["relationship"].append(relationship2dict(x))
                     elif issubclass(x.__class__, neo4j.data.Relationship):
                         _record["relationship"].append(relationship2dict(x))
+                    elif isinstance(rd, neo4j.graph.Path):
+                        _record["path"].append(path2dict(rd))
                     else:
                         _record["other"].append(rd)
+            elif isinstance(rd, neo4j.graph.Path):
+                _record["path"].append(path2dict(rd))
             else:
                 _record["other"].append(rd)
 
