@@ -227,6 +227,19 @@ class BaseHandler(RequestHandler):
                 return user
         return None
 
+    def add_create_info(self, data):
+        user: User = self.get_current_user()
+        if user:
+            data["create_user_id"] = user.id
+            data["create_user_name"] = user.username
+        data["create_time"] = datetime.now()
+
+    def add_modify_info(self, data):
+        user: User = self.get_current_user()
+        if user:
+            data["modify_user_id"] = user.id
+            data["modify_user_name"] = user.username
+        data["modify_time"] = datetime.now()
 
 class JSONEncoder(json.JSONEncoder):
     def default(self, o):
